==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl<A extends ExtensionsV1beta1SELinuxStrategyOptionsFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements ExtensionsV1beta1SELinuxStrategyOptionsFluent<A>{

    private String rule;
    private V1SELinuxOptionsBuilder seLinuxOptions;

    public ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl(){
    }
    public ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl(ExtensionsV1beta1SELinuxStrategyOptions instance){
            this.withRule(instance.getRule());

            this.withSeLinuxOptions(instance.getSeLinuxOptions());

    }

    public String getRule(){
            return this.rule;
    }

    public A withRule(String rule){
            this.rule=rule; return (A) this;
    }

    public Boolean hasRule(){
            return this.rule != null;
    }

    
/**
 * This method has been deprecated, please use method buildSeLinuxOptions instead.
 * @return The buildable object.
 */
@Deprecated public V1SELinuxOptions getSeLinuxOptions(){
            return this.seLinuxOptions!=null?this.seLinuxOptions.build():null;
    }

    public V1SELinuxOptions buildSeLinuxOptions(){
            return this.seLinuxOptions!=null?this.seLinuxOptions.build():null;
    }

    public A withSeLinuxOptions(V1SELinuxOptions seLinuxOptions){
            _visitables.remove(this.seLinuxOptions);
            if (seLinuxOptions!=null){ this.seLinuxOptions= new V1SELinuxOptionsBuilder(seLinuxOptions); _visitables.add(this.seLinuxOptions);} return (A) this;
    }

    public Boolean hasSeLinuxOptions(){
            return this.seLinuxOptions != null;
    }

    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptions(){
            return new SeLinuxOptionsNestedImpl();
    }

    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptionsLike(V1SELinuxOptions item){
            return new SeLinuxOptionsNestedImpl(item);
    }

    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editSeLinuxOptions(){
            return withNewSeLinuxOptionsLike(getSeLinuxOptions());
    }

    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptions(){
            return withNewSeLinuxOptionsLike(getSeLinuxOptions() != null ? getSeLinuxOptions(): new V1SELinuxOptionsBuilder().build());
    }

    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptionsLike(V1SELinuxOptions item){
            return withNewSeLinuxOptionsLike(getSeLinuxOptions() != null ? getSeLinuxOptions(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl that = (ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl) o;
            if (rule != null ? !rule.equals(that.rule) :that.rule != null) return false;
            if (seLinuxOptions != null ? !seLinuxOptions.equals(that.seLinuxOptions) :that.seLinuxOptions != null) return false;
            return true;
    }


    public class SeLinuxOptionsNestedImpl<N> extends V1SELinuxOptionsFluentImpl<ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<N>> implements ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1SELinuxOptionsBuilder builder;
    
            SeLinuxOptionsNestedImpl(V1SELinuxOptions item){
                    this.builder = new V1SELinuxOptionsBuilder(this, item);
            }
            SeLinuxOptionsNestedImpl(){
                    this.builder = new V1SELinuxOptionsBuilder(this);
            }
    
    public N and(){
            return (N) ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl.this.withSeLinuxOptions(builder.build());
    }
    public N endSeLinuxOptions(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl<A extends ExtensionsV1beta1SELinuxStrategyOptionsFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements ExtensionsV1beta1SELinuxStrategyOptionsFluent<A>{

    private String rule;
    private V1SELinuxOptionsBuilder seLinuxOptions;

    public ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl(){
    }
    public ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl(ExtensionsV1beta1SELinuxStrategyOptions instance){
            this.withRule(instance.getRule());

            this.withSeLinuxOptions(instance.getSeLinuxOptions());

    }

    public String getRule(){
            return this.rule;
    }

    public A withRule(String rule){
            this.rule=rule; return (A) this;
    }

    public Boolean hasRule(){
            return this.rule != null;
    }

    public A withNewRule(String arg1){
            return (A)withRule(new String(arg1));
    }

    public A withNewRule(StringBuilder arg1){
            return (A)withRule(new String(arg1));
    }

    public A withNewRule(StringBuffer arg1){
            return (A)withRule(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildSeLinuxOptions instead.
 * @return The buildable object.
 */
@Deprecated public V1SELinuxOptions getSeLinuxOptions(){
            return this.seLinuxOptions!=null?this.seLinuxOptions.build():null;
    }

    public V1SELinuxOptions buildSeLinuxOptions(){
            return this.seLinuxOptions!=null?this.seLinuxOptions.build():null;
    }

    public A withSeLinuxOptions(V1SELinuxOptions seLinuxOptions){
            _visitables.get("seLinuxOptions").remove(this.seLinuxOptions);
            if (seLinuxOptions!=null){ this.seLinuxOptions= new V1SELinuxOptionsBuilder(seLinuxOptions); _visitables.get("seLinuxOptions").add(this.seLinuxOptions);} return (A) this;
    }

    public Boolean hasSeLinuxOptions(){
            return this.seLinuxOptions != null;
    }

    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptions(){
            return new SeLinuxOptionsNestedImpl();
    }

    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptionsLike(V1SELinuxOptions item){
            return new SeLinuxOptionsNestedImpl(item);
    }

    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editSeLinuxOptions(){
            return withNewSeLinuxOptionsLike(getSeLinuxOptions());
    }

    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptions(){
            return withNewSeLinuxOptionsLike(getSeLinuxOptions() != null ? getSeLinuxOptions(): new V1SELinuxOptionsBuilder().build());
    }

    public ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptionsLike(V1SELinuxOptions item){
            return withNewSeLinuxOptionsLike(getSeLinuxOptions() != null ? getSeLinuxOptions(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl that = (ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl) o;
            if (rule != null ? !rule.equals(that.rule) :that.rule != null) return false;
            if (seLinuxOptions != null ? !seLinuxOptions.equals(that.seLinuxOptions) :that.seLinuxOptions != null) return false;
            return true;
    }


    public class SeLinuxOptionsNestedImpl<N> extends V1SELinuxOptionsFluentImpl<ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<N>> implements ExtensionsV1beta1SELinuxStrategyOptionsFluent.SeLinuxOptionsNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1SELinuxOptionsBuilder builder;
    
            SeLinuxOptionsNestedImpl(V1SELinuxOptions item){
                    this.builder = new V1SELinuxOptionsBuilder(this, item);
            }
            SeLinuxOptionsNestedImpl(){
                    this.builder = new V1SELinuxOptionsBuilder(this);
            }
    
    public N and(){
            return (N) ExtensionsV1beta1SELinuxStrategyOptionsFluentImpl.this.withSeLinuxOptions(builder.build());
    }
    public N endSeLinuxOptions(){
            return and();
    }

}


}
